@@ -1,23 +1,25 @@
-/* Glide theme engine
- * Copyright (C) 2006 Andrew Johnson
+/* Glide - a cairo based GTK+ engine
+ * Copyright (C) 2006 Andrew Johnson <acjgenius@earthlink.net>
+ * Copyright (C) 2006-2007 Benjamin Berg <benjamin@sipsolutions.net>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Project contact: <gnome-themes-list@gnome.org>
  *
- * Written by Andrew Johnson <acjgenius@earthlink.net>
- */ 
+ */
+
 
 #include <string.h>
 #include "glide_gtk2_engine.h"
@@ -213,8 +215,6 @@ glide_draw_option (GtkStyle * style,
              gint height)
 {
 	GlideCheckState check_state;
-	gboolean observe_shadow;
-	gboolean draw_check;
 
 	GlideStyle *glide_style;
  
@@ -263,8 +263,6 @@ glide_draw_option (GtkStyle * style,
 	/***********************************************/
 	/* Appearance                                  */
 	/***********************************************/
-	observe_shadow = FALSE;
-	draw_check = !observe_shadow;
 
 
 		/***********************************************/
@@ -281,11 +279,6 @@ glide_draw_option (GtkStyle * style,
 			check_color = &glide_style->color_cube.dark[state];	
 		}
 
-		if (observe_shadow)
-		{
-			fill_color = &glide_style->color_cube.bg[state];
-		}
-
 
 		/***********************************************/
 		/* Style                                       */
@@ -293,43 +286,6 @@ glide_draw_option (GtkStyle * style,
 		bevel_style = GLIDE_BEVEL_STYLE_SMOOTHER;
 		border_type = GLIDE_BORDER_TYPE_IN;
 
-		if (observe_shadow)
-		{
-			/*border_type = glide_gtk_shadow(shadow);*/
-
-			/***********************************************/
-			/* Convert Shadow Type To Border Type          */
-			/***********************************************/
-			switch (shadow)
-			{
-				case GTK_SHADOW_ETCHED_IN:
-					border_type = GLIDE_BORDER_TYPE_ETCHED;
-				break;
-
-				case GTK_SHADOW_ETCHED_OUT:
-					border_type = GLIDE_BORDER_TYPE_ENGRAVED;
-				break;
-
-				case GTK_SHADOW_IN:
-					border_type = GLIDE_BORDER_TYPE_IN;
-				break;
-
-				case GTK_SHADOW_OUT:
-					border_type = GLIDE_BORDER_TYPE_OUT;
-				break;
-
-				default:
-					border_type = GLIDE_BORDER_TYPE_NONE;
-				break;
-			}
-
-			if (!draw_check)
-			{
-				check_state = GLIDE_CHECK_OFF;
-			}
-		}
-
-
 	/***********************************************/
 	/* Draw Option                                 */
 	/***********************************************/
@@ -725,6 +681,7 @@ glide_draw_combobox_button (GtkStyle * style,
   		            area, widget, "combo_box_entry", x - thick*2 - focus - focus_padding, y + focus - focus_padding, 
 				width + thick*2 + focus_padding*2, height - focus*2 + focus_padding*2);
         }
+#ifndef GTK_DISABLE_DEPRECATED
       else if (ge_is_combo(widget))
         {
           GtkWidget *entry = widget;
@@ -771,6 +728,9 @@ glide_draw_combobox_button (GtkStyle * style,
 				width + thick*2 + focus_padding*2, height - focus*2 + focus_padding*2);
           }
         }
+#else
+#warning Disabling GtkCombo support because GTK_DISABLE_DEPRECATED is enabled.
+#endif /* GTK_DISABLE_DEPRECATED */
       else
         {
           GtkWidget *parent = widget;
@@ -863,6 +823,7 @@ glide_draw_combobox_button (GtkStyle * style,
                                 x + focus - focus_padding, y + focus - focus_padding, 
                                 width + thick*2 - focus + focus_padding*2, height - focus*2 + focus_padding*2);
         }
+#ifndef GTK_DISABLE_DEPRECATED
       else if (ge_is_combo(widget))
         {
           GtkWidget *entry = widget;
@@ -896,6 +857,9 @@ glide_draw_combobox_button (GtkStyle * style,
                                 x + focus - focus_padding, y + focus - focus_padding, 
                                 width + thick*2 - focus + focus_padding*2, height - focus*2 + focus_padding*2);
         }
+#else
+#warning Disabling GtkCombo support because GTK_DISABLE_DEPRECATED is enabled.
+#endif /* GTK_DISABLE_DEPRECATED */
       else
         {
           GtkWidget *parent = widget;
@@ -1581,8 +1545,12 @@ glide_draw_flat_box (GtkStyle * style,
 		cairo_destroy(canvas);
 	}
 	else
+	{
+		GtkStyleClass *glide_parent_class;
+		glide_parent_class = GTK_STYLE_CLASS (g_type_class_peek_parent (G_OBJECT_GET_CLASS(style)));
 		glide_parent_class->draw_flat_box (style, window, state_type, shadow_type, area,
 							widget, detail, x, y, width, height);
+	}
 }
 
 /***********************************************
@@ -2256,6 +2224,8 @@ glide_draw_focus(GtkStyle *style,
 
 	if (interior_focus)
 	{
+		GtkStyleClass *glide_parent_class;
+		glide_parent_class = GTK_STYLE_CLASS (g_type_class_peek_parent (G_OBJECT_GET_CLASS(style)));
 		glide_parent_class->draw_focus(style, window, state_type, area, widget, detail, x, y, width, height);
 	}
 	else
